package com.despark.tuning3d.model.settings {
	import com.distriqt.extension.application.Application;
	import com.distriqt.extension.application.OperatingSystem;
	import com.utils.FileUtil;

	import flash.filesystem.File;

	public class Settings {
		public var autoscrollEnabled : Boolean = true;
		public var selectedLanguageCode : String;

		private static var mainSettings:File;
		private static var _soundOn:Boolean = true;
		private static var _isEightFrame:Boolean = false;
		private static var _hd_only:Boolean = true;
		private static var _settingsObject:Object = {};
		public static function init():void{
			mainSettings = File.applicationStorageDirectory.resolvePath("main_settings.json");
			if(mainSettings.exists){
				var settingsStr:String = FileUtil.getFileContent(mainSettings);
				if(settingsStr && settingsStr.length){
					_settingsObject = JSON.parse(settingsStr);
					if(_settingsObject.hasOwnProperty("sound")){
						_soundOn = _settingsObject["sound"];
					}
					if(_settingsObject.hasOwnProperty("hd_only")){
						_hd_only = _settingsObject["hd_only"];
					}
					if(_settingsObject.hasOwnProperty("eight_frame")){
						_isEightFrame = _settingsObject["eight_frame"];
					}else {
						setEightFrameByOS();
					}
				}else{
					setEightFrameByOS();
				}
				resetSettings();
			}else{
				setEightFrameByOS();
				resetSettings();
			}
		}

		private static function resetSettings():void{
			_settingsObject = {"sound": _soundOn, "eight_frame": _isEightFrame, "hd_only": _hd_only};
		}

		private static function setEightFrameByOS():void{
			if(Application.isSupported){
				var os:OperatingSystem = (Application.service && Application.service.device && Application.service.device.os)?Application.service.device.os:null;
				if(os){
					if((os.name && os.name.toLowerCase() == "android") || (os.type && os.type.toLowerCase() == "android")){
						_isEightFrame = (parseFloat(os.version) < 11);
					}else if((os.name && os.name.toLowerCase() == "ios") || (os.type && os.type.toLowerCase() == "ios")){
						_isEightFrame = (parseFloat(os.version) < 14);
					}
				}
			}
		}

		public static function getDeviceInfo():String{
			if(Application.isSupported) {
				var os:OperatingSystem = (Application.service && Application.service.device && Application.service.device.os) ? Application.service.device.os : null;
				var result:String = os.name + " " + os.version + ", " + Application.service.device.brand + " " + Application.service.device.model;
				return result;
			}
			return "no info";
		}

		public static function get soundOn():Boolean {
			return _soundOn;
		}

		public static function set soundOn(value:Boolean):void {
			_soundOn = value;
			if(_settingsObject.sound != value){
				_settingsObject.sound = value;
				FileUtil.putFileContent(mainSettings, JSON.stringify(_settingsObject));
			}
		}

		public static function get isEightFrame():Boolean {
			return _isEightFrame;
		}

		public static function set isEightFrame(value:Boolean):void {
			_isEightFrame = value;
			if(value != _settingsObject.eight_frame){
				_settingsObject.eight_frame = value;
				FileUtil.putFileContent(mainSettings, JSON.stringify(_settingsObject));
			}
		}

		public static function get hdOnly():Boolean {
			return _hd_only;
		}

		public static function set hdOnly(value:Boolean):void {
			_hd_only = value;
			if(_settingsObject.hd_only != value){
				_settingsObject.hd_only = value;
				FileUtil.putFileContent(mainSettings, JSON.stringify(_settingsObject));
			}
		}
	}

}